<?php
namespace Teknisa\PLA\Modules\Medicao\Services;

use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Setforms2\Shared\ORM\DateTime;
use \Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use \Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DataSource;

class Pla04200ImportacaoEfetivoService {

	protected $util;
    protected $dataSourceManager;
    protected $environment;
    protected $entityManager;
    protected $connection;
    protected $crudService;

	public function __construct($util, $dataSourceManager, $environment, $entityManager, $crudService) {
        $this->util          = $util;
        $this->environment   = $environment;
        $this->entityManager = $entityManager;
        $this->connection    = $entityManager->getConnection();
        $this->crudService   = $crudService;
	}
	
	public function verificaClienteApurado($row) {
	    try { 
    	    $sql = "SELECT CDFILIAL, CDSERVFILI, DTEFETCLIE, CDCLIENTE, NRAPURACFAT
                      FROM EFETCLIE 
                    WHERE CDFILIAL = :P_CDFILIAL
                      AND CDSERVFILI = :P_CDSERVFILI
                      AND DTEFETCLIE = :P_DTCARDAPIO";
            
            $params = array(
                "P_CDFILIAL"   => $row['CDFILIAL'],
                "P_CDSERVFILI" => $row['CDSERVFILI'],
                "P_DTCARDAPIO" => $row['DTCARDAPIO']
            );
            
            $query = $this->connection->prepare($sql);
            $query->execute($params);
            return $query->fetchAll();
	    } catch(\Exception $e) {
	        throw $e;
	    }
	}
	
	public function updateEfetPla($row) {
	    try { 
    	    $sql = " UPDATE CARDADIA
                        SET QTCLIEFETCAR = :QTCLIEFETCAR,
                            QTCOMEFETCAR = :QTCLIEFETCAR + QTFUNEFETCAR + QTDOAEFETCAR
                        WHERE CDFILIAL = :P_CDFILIAL AND
                              CDSERVFILI = :P_CDSERVFILI AND
                              DTCARDAPIO = :P_DTCARDAPIO";
                              
            $params = array(
                "QTCLIEFETCAR" => $row['QTCLIEFETCAR'],
                "P_CDFILIAL"   => $row['CDFILIAL'],
                "P_CDSERVFILI" => $row['CDSERVFILI'],
                "P_DTCARDAPIO" => $row['DTCARDAPIO']
            );
            
            $query = $this->connection->prepare($sql);
            $query->execute($params);
        } catch(\Exception $e) {
            throw $e;
        }
	}
	
	public function updateEfetPlaTipoPrat($row) {
	    try { 
    	    $sql = " UPDATE COMPCARD
                        SET QTCOMEFETPRA = ((SELECT QTCOMEFETCAR FROM CARDADIA WHERE CDFILIAL = :P_CDFILIAL AND NRCARDAPIO = :P_NRCARDAPIO) * VRPECONSCARD)/100
                        WHERE CDFILIAL   = :P_CDFILIAL AND
                              NRCARDAPIO = :P_NRCARDAPIO";
                              
            
            $params = array(
                "P_CDFILIAL"   => $row['CDFILIAL'],
                "P_NRCARDAPIO" => $row['NRCARDAPIO']
            );
            
            $query = $this->connection->prepare($sql);
            $query->execute($params);
	    } catch(\Exception $e) {
            throw $e;
        }
	}
	
	public function insertEfetCli($efetcli) {
	    try {
    	    $dataSourceName = "efetclie";
            $dataSet = new DataSet($dataSourceName, array($efetcli));
            $request = new DTO\Request\DataSet($dataSet, "", "", "");
            $rowsToSave = $this->crudService->getRowsToSave($request, $dataSourceName);
            $this->crudService->save($dataSourceName, $rowsToSave);
    	} catch(\Exception $e) {
            throw $e;
        }
	}
	
	public function updateEfetCliNaoApurados($params) {
	    try {
    	    $sql = " UPDATE EFETCLIE
                        SET QTCOMEFETCLI = :QTCOMEFETCLI
                      WHERE CDFILIAL = :P_CDFILIAL AND
                            CDSERVFILI = :P_CDSERVFILI AND
                            DTEFETCLIE =:P_DTCARDAPIO AND
                            CDCLIENTE = :P_CDCLIENTE";
            
            $query = $this->connection->prepare($sql);
            $query->execute($params);
	    } catch(\Exception $e) {
            throw $e;
        }
	}
	
	public function verificaCardapio($row) {
	    try {
    	    $sql = "   SELECT MAX(NRCARDAPIO) AS NRCARDAPIO
                         FROM CARDADIA C 
                        WHERE C.CDFILIAL = :P_CDFILIAL
                          AND C.CDSERVFILI = :P_CDSERVFILI 
                          AND C.DTCARDAPIO = :P_DTCARDAPIO";
                              
            $params = array(
                "P_CDFILIAL"   => $row['CDFILIAL'],
                "P_CDSERVFILI" => $row['CDSERVFILI'],
                "P_DTCARDAPIO" => $row['DTCARDAPIO']
            );
            
            $query = $this->connection->prepare($sql);
            $query->execute($params);
            return $query->fetchAll();
	    } catch(\Exception $e) {
            throw $e;
        }
	}
}